<?xml version="1.0"?>
<!-- 
(c)2006 David Sporn

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public
License version 2.1 as published by the Free Software Foundation.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="text"/>

<!-- ===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-=== -->
<!-- Root node conversion -->
<xsl:template match="FormBody">
	<xsl:variable name="layout">
		<xsl:choose>
			<xsl:when test="string-length(@layout)>0"><xsl:value-of select="@layout"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="Div"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="$layout='List'">
<![CDATA[<ul id="<?php echo $formBodyNameSpace.']]><xsl:value-of select="@classname"/><![CDATA[' ; ?>">]]>
				<xsl:apply-templates select="field|group" mode="List"/>
<![CDATA[</ul>]]>
		</xsl:when>
		<xsl:otherwise>
<![CDATA[<div id="<?php echo $formBodyNameSpace.']]><xsl:value-of select="@classname"/><![CDATA[' ; ?>">]]>
				<xsl:apply-templates select="field|group" mode="Div"/>
<![CDATA[</div>]]>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- ===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-=== -->
<!-- Layout independant conversions -->

<!-- Default rendering : none -->
<xsl:template match="field">
</xsl:template>

<!-- hidden fields -->
<xsl:template match="field[@type = 'hidden']">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<input type="hidden" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA[" value="]]><xsl:value-of select="$field_value"/><![CDATA[" />]]>
</xsl:template>

<!-- Group default rendering -->
<xsl:template match="group">
	<xsl:apply-templates/>
</xsl:template>

<!-- options rendering for a select box-->
<xsl:template match="field[@type = 'selectbox']/option">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../@property) > 0"><xsl:value-of select="../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
			<![CDATA[<option value="]]><xsl:value-of select="@value"/><![CDATA[" <?php if (]]><xsl:value-of select="$field_value_test"/><![CDATA[){?>checked="checked"<?php }?>>]]><xsl:value-of select="$label_value"/><![CDATA[</option>]]>
</xsl:template>

<!-- options group rendering for a select box-->
<xsl:template match="field[@type = 'selectbox']/group">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../@property) > 0"><xsl:value-of select="../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_expr"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="$label_expr"/><![CDATA[, ENT_COMPAT) ;?>]]></xsl:variable>
			<![CDATA[<optgroup label="]]><xsl:value-of select="$label_value"/><![CDATA[">]]>
				<xsl:apply-templates select="option"/>
			<![CDATA[</optgroup>]]>
</xsl:template>

<!-- options rendering inside a group for a select box-->
<xsl:template match="field[@type = 'selectbox']/group/option">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../../@property) > 0"><xsl:value-of select="../../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
				<![CDATA[<option value="]]><xsl:value-of select="@value"/><![CDATA[" <?php if (]]><xsl:value-of select="$field_value_test"/><![CDATA[){?>checked="checked"<?php }?>>]]><xsl:value-of select="$label_value"/><![CDATA[</option>]]>
</xsl:template>

<!-- options rendering inside an optgroup-->
<xsl:template match="field[@type = 'selectbox']/option">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../../@property) > 0"><xsl:value-of select="../../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
			<![CDATA[<option value="]]><xsl:value-of select="@value"/><![CDATA[" <?php if (]]><xsl:value-of select="$field_value_test"/><![CDATA[){?>checked="checked"<?php }?>>]]><xsl:value-of select="$label_value"/><![CDATA[</option>]]>
</xsl:template>


<!-- ===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-=== -->
<!-- Layout = Div -->

<!-- ===-===-===-===-===-===-=== -->
<!-- fields -->

<xsl:template match="field[@type = 'hidden']" mode="Div">
	<xsl:apply-templates select="."/>
</xsl:template>

<xsl:template match="group" mode="Div">
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<![CDATA[<fieldset>]]>
		<![CDATA[<legend>]]><xsl:value-of select="$label_value"/><![CDATA[</legend>]]>
		<xsl:apply-templates select="field|group" mode="Div"/>
	<![CDATA[</fieldset>]]>
</xsl:template>

<xsl:template match="field[@type = 'SingleLineText']" mode="Div">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<div class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label for="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<input type="text" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA[" value="]]><xsl:value-of select="$field_value"/><![CDATA[" />]]>
	<![CDATA[</div>]]>
</xsl:template>

<!-- Password fields are rendered with an empty value -->
<xsl:template match="field[@type = 'password']" mode="Div">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<div class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label for="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<input type="password" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA[" value="" />]]>
	<![CDATA[</div>]]>
</xsl:template>

<xsl:template match="field[@type = 'text']" mode="Div">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_NOQUOTES) ;?>]]></xsl:variable>
	<![CDATA[<div class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label for="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<textarea name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$field_value"/><![CDATA[</textarea>]]>
	<![CDATA[</div>]]>
</xsl:template>

<xsl:template match="field[@type = 'radio']" mode="Div">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<div class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label>]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<xsl:choose>
			<xsl:when test="@layout='List'">
		<![CDATA[<ul>]]>
					<xsl:apply-templates select="option" mode="List"/>
		<![CDATA[</ul>]]>
			</xsl:when>
			<xsl:otherwise>
		<![CDATA[<div>]]>
					<xsl:apply-templates select="option" mode="Div"/>
		<![CDATA[</div>]]>
			</xsl:otherwise>
		</xsl:choose>
	<![CDATA[</div>]]>
</xsl:template>

<xsl:template match="field[@type = 'checkbox']" mode="Div">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<div class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label>]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<xsl:choose>
			<xsl:when test="@layout='List'">
		<![CDATA[<ul>]]>
					<xsl:apply-templates select="option" mode="List"/>
		<![CDATA[</ul>]]>
			</xsl:when>
			<xsl:otherwise>
		<![CDATA[<div>]]>
					<xsl:apply-templates select="option" mode="Div"/>
		<![CDATA[</div>]]>
			</xsl:otherwise>
		</xsl:choose>
	<![CDATA[</div>]]>
</xsl:template>

<xsl:template match="field[@type = 'selectbox']" mode="Div">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<xsl:variable name="multiple_value"><xsl:if test="@multiple='true'"><![CDATA[ multiple="multiple"]]></xsl:if></xsl:variable>
	<![CDATA[<div class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label>]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<select name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA["]]><xsl:value-of select="$multiple_value"/><![CDATA[>]]>
			<xsl:apply-templates select="option|group"/>
		<![CDATA[</select>]]>
	<![CDATA[</div>]]>
</xsl:template>

<!-- ===-===-===-===-===-===-=== -->
<!-- options rendering -->
<xsl:template match="field[@type = 'radio']/option" mode="Div">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../@property) > 0"><xsl:value-of select="../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
			<![CDATA[<div>]]>
				<![CDATA[<input type="radio" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[" value="]]><xsl:value-of select="@value"/><![CDATA[" <?php if (]]><xsl:value-of select="$field_value_test"/><![CDATA[){?>checked="checked"<?php }?>/>]]>
				<![CDATA[<label for="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
			<![CDATA[</div>]]>
</xsl:template>

<xsl:template match="field[@type = 'checkbox']/option" mode="Div">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../@property) > 0"><xsl:value-of select="../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
			<![CDATA[<div>]]>
				<![CDATA[<input type="checkbox" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[" value="]]><xsl:value-of select="@value"/><![CDATA[" <?php if (]]><xsl:value-of select="$field_value_test"/><![CDATA[){?>checked="checked"<?php }?>/>]]>
				<![CDATA[<label for="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
			<![CDATA[</div>]]>
</xsl:template>

<!-- ===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-===-=== -->
<!-- Layout = List -->

<!-- ===-===-===-===-===-===-=== -->
<!-- fields -->
<xsl:template match="field[@type = 'hidden']" mode="List">
	<xsl:apply-templates select="."/>
</xsl:template>

<xsl:template match="group" mode="List">
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<![CDATA[<li><fieldset>]]>
		<![CDATA[<legend>]]><xsl:value-of select="$label_value"/><![CDATA[</legend>]]>
		<![CDATA[<ul>]]>
			<xsl:apply-templates select="field|group" mode="List"/>
		<![CDATA[</ul>]]>
	<![CDATA[</fieldset></li>]]>
</xsl:template>

<xsl:template match="field[@type = 'SingleLineText']" mode="List">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<li class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label for="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<input type="text" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA[" value="]]><xsl:value-of select="$field_value"/><![CDATA[" />]]>
	<![CDATA[</li>]]>
</xsl:template>

<!-- Password fields are rendered with an empty value -->
<xsl:template match="field[@type = 'password']" mode="List">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<li class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label for="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<input type="password" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA[" value="" />]]>
	<![CDATA[</li>]]>
</xsl:template>

<xsl:template match="field[@type = 'text']" mode="List">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_NOQUOTES) ;?>]]></xsl:variable>
	<![CDATA[<li class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label for="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<textarea name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA[">]]><xsl:value-of select="$field_value"/><![CDATA[</textarea>]]>
	<![CDATA[</li>]]>
</xsl:template>

<xsl:template match="field[@type = 'radio']" mode="List">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<li class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label>]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<xsl:choose>
			<xsl:when test="@layout='List'">
		<![CDATA[<ul>]]>
					<xsl:apply-templates select="option" mode="List"/>
		<![CDATA[</ul>]]>
			</xsl:when>
			<xsl:otherwise>
		<![CDATA[<div>]]>
					<xsl:apply-templates select="option" mode="Div"/>
		<![CDATA[</div>]]>
			</xsl:otherwise>
		</xsl:choose>
	<![CDATA[</li>]]>
</xsl:template>

<xsl:template match="field[@type = 'checkbox']" mode="List">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<![CDATA[<li class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label>]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<xsl:choose>
			<xsl:when test="@layout='List'">
		<![CDATA[<ul>]]>
					<xsl:apply-templates select="option" mode="List"/>
		<![CDATA[</ul>]]>
			</xsl:when>
			<xsl:otherwise>
		<![CDATA[<div>]]>
					<xsl:apply-templates select="option" mode="Div"/>
		<![CDATA[</div>]]>
			</xsl:otherwise>
		</xsl:choose>
	<![CDATA[</li>]]>
</xsl:template>

<xsl:template match="field[@type = 'selectbox']" mode="List">
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(@property) > 0"><xsl:value-of select="@property"/></xsl:when><xsl:otherwise><xsl:value-of select="@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value"><![CDATA[<?php echo htmlspecialchars($]]><xsl:value-of select="@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[(), ENT_COMPAT) ;?>]]></xsl:variable>
	<xsl:variable name="multiple_value"><xsl:if test="@multiple='true'"><![CDATA[ multiple="multiple"]]></xsl:if></xsl:variable>
	<![CDATA[<li class="]]><xsl:value-of select="$id_value"/><![CDATA[">]]>
		<![CDATA[<label>]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
		<![CDATA[<select name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="$id_value"/><![CDATA["]]><xsl:value-of select="$multiple_value"/><![CDATA[>]]>
			<xsl:apply-templates select="option|group"/>
		<![CDATA[</select>]]>
	<![CDATA[</li>]]>
</xsl:template>


<!-- ===-===-===-===-===-===-=== -->
<!-- options rendering -->
<xsl:template match="field[@type = 'radio']/option" mode="List">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../@property) > 0"><xsl:value-of select="../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
			<![CDATA[<li>]]>
				<![CDATA[<input type="radio" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[" value="]]><xsl:value-of select="@value"/><![CDATA[" <?php if (]]><xsl:value-of select="$field_value_test"/><![CDATA[){?>checked="checked"<?php }?>/>]]>
				<![CDATA[<label for="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
			<![CDATA[</li>]]>
</xsl:template>

<xsl:template match="field[@type = 'checkbox']/option" mode="List">
	<xsl:variable name="property_name"><xsl:choose><xsl:when test="string-length(../@property) > 0"><xsl:value-of select="../@property"/></xsl:when><xsl:otherwise><xsl:value-of select="../@name"/></xsl:otherwise></xsl:choose></xsl:variable>
	<xsl:variable name="field_value_expr"><![CDATA[$]]><xsl:value-of select="../@valueSource"/><![CDATA[->get]]><xsl:value-of select="$property_name"/><![CDATA[()]]></xsl:variable>
	<xsl:variable name="field_value_test"><![CDATA[(]]><xsl:value-of select="$field_value_expr"/><![CDATA[==']]><xsl:value-of select="@value"/><![CDATA[')]]></xsl:variable>
	<xsl:variable name="id_value"><![CDATA[<?php echo $formBodyNameSpace.']]><xsl:value-of select="../@name"/><![CDATA[' ;?>]]></xsl:variable>
	<xsl:variable name="label_value"><![CDATA[<?php echo(]]><xsl:value-of select="/FormBody/@ResourceCall"/><![CDATA[(']]><xsl:value-of select="@labelKey"/><![CDATA[')) ;?>]]></xsl:variable>
			<![CDATA[<li>]]>
				<![CDATA[<input type="checkbox" name="]]><xsl:value-of select="$id_value"/><![CDATA[" id="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[" value="]]><xsl:value-of select="@value"/><![CDATA[" <?php if (]]><xsl:value-of select="$field_value_test"/><![CDATA[){?>checked="checked"<?php }?>/>]]>
				<![CDATA[<label for="]]><xsl:value-of select="concat($id_value,'_',@value)"/><![CDATA[">]]><xsl:value-of select="$label_value"/><![CDATA[</label>]]>
			<![CDATA[</li>]]>
</xsl:template>

</xsl:stylesheet>